/*
 * Changes to this file committed after and not including commit-id: ccc0d2c5f9a5ac661e60e6eaf138de7889928b8b
 * are released under the following license:
 *
 * This file is part of Hopsworks
 * Copyright (C) 2018, Logical Clocks AB. All rights reserved
 *
 * Hopsworks is free software: you can redistribute it and/or modify it under the terms of
 * the GNU Affero General Public License as published by the Free Software Foundation,
 * either version 3 of the License, or (at your option) any later version.
 *
 * Hopsworks is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with this program.
 * If not, see <https://www.gnu.org/licenses/>.
 *
 * Changes to this file committed before and including commit-id: ccc0d2c5f9a5ac661e60e6eaf138de7889928b8b
 * are released under the following license:
 *
 * Copyright (C) 2013 - 2018, Logical Clocks AB and RISE SICS AB. All rights reserved
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS  OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package io.hops.hopsworks.kmon.user;

import io.hops.hopsworks.common.dao.user.UserFacade;
import io.hops.hopsworks.common.dao.user.Users;
import io.hops.hopsworks.exceptions.UserException;
import io.hops.hopsworks.common.user.AuthController;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.ejb.EJBException;
import javax.faces.application.FacesMessage;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;
import javax.inject.Inject;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.Serializable;
import java.util.logging.Level;
import java.util.logging.Logger;

@ManagedBean
@SessionScoped
public class LoginBean implements Serializable {

  private final static Logger LOGGER = Logger.getLogger(LoginBean.class.getName());
  @EJB
  private UserFacade userFacade;
  @EJB
  private AuthController authController;
  @Inject
  private Credentials credentials;

  private Users user;
  private boolean twoFactor;

  @PostConstruct
  public void init() {
    twoFactor = false;
  }

  public boolean isTwoFactor() {
    return twoFactor;
  }

  public void setTwoFactor(boolean twoFactor) {
    this.twoFactor = twoFactor;
  }

  public Credentials getCredentials() {
    return credentials;
  }

  public void setCredentials(Credentials credentials) {
    this.credentials = credentials;
  }

  public Users getUser() {
    return user;
  }

  public void setUser(Users user) {
    this.user = user;
  }

  public Users getUserFromSession() {
    if (user == null) {
      ExternalContext context = FacesContext.getCurrentInstance().getExternalContext();
      String userEmail = context.getUserPrincipal().getName();
      user = userFacade.findByEmail(userEmail);
    }
    return user;
  }

  public String loginUsername() {
    this.user = getUserFromSession();
    if (this.user != null) {
      return user.getFname() + " " + user.getLname();
    }
    return "No username";
  }

  public String login() {
    FacesContext context = FacesContext.getCurrentInstance();
    HttpServletRequest request = (HttpServletRequest) context.getExternalContext().getRequest();
    this.user = userFacade.findByEmail(this.credentials.getUsername());
    if (user == null) {
      context.addMessage(null, new FacesMessage("Login failed. User " + this.credentials.getUsername()));
      return "";
    }
    String passwordWithSaltPlusOtp;
    try {
      passwordWithSaltPlusOtp = authController.preCustomRealmLoginCheck(user, this.credentials.getPassword(),
          this.credentials.getOtp(), request);
    } catch (UserException ex) {
      LOGGER.log(Level.SEVERE, null, ex);
      context.addMessage(null, new FacesMessage("Login failed."));
      return "";
    } catch (EJBException ie) {
      String msg = ie.getCausedByException().getMessage();
      if (msg != null && !msg.isEmpty() && msg.contains("Second factor required.")) {
        setTwoFactor(true);
      }
      context.addMessage(null, new FacesMessage(msg));
      return "login";
    }
    try {
      request.login(this.credentials.getUsername(), passwordWithSaltPlusOtp);
      authController.registerLogin(user, request);
    } catch (ServletException e) {
      authController.registerAuthenticationFailure(user, request);
      context.addMessage(null, new FacesMessage("Login failed."));
      return "";
    }
    return "monitoring";
  }

  public String logOut() {
    try {
      this.user = getUserFromSession();
      HttpServletRequest req = (HttpServletRequest) FacesContext.getCurrentInstance().getExternalContext().getRequest();
      req.getSession().invalidate();
      req.logout();
      if (user != null) {
        authController.registerLogout(user, req);
      }
      FacesContext.getCurrentInstance().getExternalContext().redirect("/hopsworks/#!/home");
    } catch (IOException | ServletException ex) {
      LOGGER.log(Level.SEVERE, null, ex);
    }
    return "login";
  }

  public boolean isLoggedIn() {
    HttpServletRequest req = (HttpServletRequest) FacesContext.getCurrentInstance().getExternalContext().getRequest();
    return req.getRemoteUser() != null;
  }

  public void checkAlreadyLoggedin() throws IOException {
    if (isLoggedIn()) {
      ExternalContext ec = FacesContext.getCurrentInstance().getExternalContext();
      ec.redirect(ec.getRequestContextPath() + "/monitor/clusters.xhtml");
    }
  }

  public void gotoSupport() throws IOException {
    String link = "https://groups.google.com/forum/#!forum/hopshadoop";
    ExternalContext externalContext = FacesContext.getCurrentInstance().getExternalContext();
    externalContext.redirect(link.trim());
  }

  public void gotoLoginHelp() throws IOException {
    String link = "/hopsworks-admin/security/login_issue.xhtml";
    ExternalContext externalContext = FacesContext.getCurrentInstance().getExternalContext();
    externalContext.redirect(link.trim());
  }
}
